<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = get_option( 'stylesheet' );
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'options_framework_theme'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);

	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Typography Defaults
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'georgia',
		'style' => 'bold',
		'color' => '#bada55' );
		
	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/images/';

	$options = array();
	
		$options[] = array(
		'name' => __('Colors', 'options_framework_theme'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Color Scheme', 'options_check'),
		'desc' => __('Switch to dark color scheme', 'options_check'),
		'id' => 'dark_theme',
		'std' => '0',
		'type' => 'checkbox');
		
	$options[] = array(
		'name' => __('Text color', 'options_check'),
		'desc' => __('The color for text on the site.', 'options_check'),
		'id' => 'text_color',
		'std' => '',
		'type' => 'color' );
		
	$options[] = array(
		'name' => __('Headings color', 'options_check'),
		'desc' => __('The color for headings on the site.', 'options_check'),
		'id' => 'headings_color',
		'std' => '',
		'type' => 'color' );
		
	$options[] = array(
		'name' => __('Artist Name Color', 'options_check'),
		'desc' => __('This is the color of the title at the top of your site (unless you upload a logo image to replace it)', 'options_check'),
		'id' => 'title_color',
		'std' => '',
		'type' => 'color' );
	
	$options[] = array(
		'name' => __('Links color', 'options_check'),
		'desc' => __('The color for links on the site.', 'options_check'),
		'id' => 'links',
		'std' => '',
		'type' => 'color' );

	$options[] = array(		
		'name' => __('Links hover color', 'options_check'),
		'desc' => __('The color for links when the mouse hovers over them.', 'options_check'),
		'id' => 'links_hover',
		'std' => '',
		'type' => 'color' );
		
		
	$options[] = array(
		'name' => __('Menu links color', 'options_check'),
		'desc' => __('The color for menu links.', 'options_check'),
		'id' => 'menu_color',
		'std' => '',
		'type' => 'color' );
		

	$options[] = array(
		'name' => __('Menu links hover color', 'options_check'),
		'desc' => __('The color for menu links when the mouse hovers over them.', 'options_check'),
		'id' => 'menu_hover',
		'std' => '',
		'type' => 'color' );
		
	$options[] = array(
		'name' => __('Footer links color', 'options_check'),
		'desc' => __('The color for footer links.', 'options_check'),
		'id' => 'footer_color',
		'std' => '',
		'type' => 'color' );
		
	$options[] = array(
		'name' => __('Footer links hover color', 'options_check'),
		'desc' => __('The color for footer links when the mouse hovers over them.', 'options_check'),
		'id' => 'footer_hover',
		'std' => '',
		'type' => 'color' );
		
	$options[] = array(
		'name' => __('Background color', 'options_check'),
		'desc' => __('The color of the site background.', 'options_check'),
		'id' => 'background_color',
		'std' => '',
		'type' => 'color' );
		
	$options[] = array(
		'name' => __('Main content area color', 'options_check'),
		'desc' => __('The backround color for the content areas of the site.', 'options_check'),
		'id' => 'content_color',
		'std' => '',
		'type' => 'color' );
	$options[] = array(
		'name' => __('Header', 'options_framework_theme'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Logo', 'options_framework_theme'),
		'desc' => __('Your Logo', 'options_framework_theme'),
		'id' => 'logo',
		'type' => 'upload');

	$options[] = array(
		'name' => __('RSS Feed', 'options_framework_theme'),
		'desc' => __('Your RSS feed URL - must include "http://"', 'options_framework_theme'),
		'id' => 'rss_feed',
		'std' => '',
		'type' => 'text');
	
	$options[] = array(
		'name' => __('Facebook URL', 'options_framework_theme'),
		'desc' => __('Your Facebook URL - must include "http://"', 'options_framework_theme'),
		'id' => 'facebook_url',
		'std' => '',
		'type' => 'text');

	$options[] = array(
		'name' => __('Twitter URL', 'options_framework_theme'),
		'desc' => __('Your Twitter URL - must include "http://"', 'options_framework_theme'),
		'id' => 'twitter_url',
		'std' => '',
		'type' => 'text');

	$options[] = array(
		'name' => __('YouTube URL', 'options_framework_theme'),
		'desc' => __('Your YouTube URL - must include "http://"', 'options_framework_theme'),
		'id' => 'youtube_url',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Pinterest', 'options_framework_theme'),
		'desc' => __('Your Pinterest URL - must include "http://"', 'options_framework_theme'),
		'id' => 'pinterest_url',
		'std' => '',
		'type' => 'text');

	$options[] = array(
		'name' => __('Google Plus URL', 'options_framework_theme'),
		'desc' => __('Your Google Plus URL - must include "http://"', 'options_framework_theme'),
		'id' => 'google_plus_url',
		'std' => '',
		'type' => 'text');

	$options[] = array(
		'name' => __('Vimeo URL', 'options_framework_theme'),
		'desc' => __('Your Vimeo URL - must include "http://"', 'options_framework_theme'),
		'id' => 'vimeo_url',
		'std' => '',
		'type' => 'text'); 

	$options[] = array(
		'name' => __('Myspace URL', 'options_framework_theme'),
		'desc' => __('Your Myspace URL - must include "http://"', 'options_framework_theme'),
		'id' => 'myspace_url',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Sidebar', 'options_framework_theme'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Enable Arrow', 'options_check'),
		'desc' => __('Add a red arrow that points down towards your opt-in form', 'options_check'),
		'id' => 'sidebar_arrow',
		'std' => '0',
		'type' => 'checkbox');

	$options[] = array(
		'name' => __('Footer', 'options_framework_theme'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Copyright', 'options_framework_theme'),
		'desc' => __('The copyright info in the footer', 'options_framework_theme'),
		'id' => 'copyright',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Home', 'options_framework_theme'),
		'type' => 'heading' );

	$options[] = array(		
		'name' => __('Hide Home Page Content', 'options_check'),
		'desc' => __('Check this box to remove the home page content box.', 'options_check'),
		'id' => 'home_content',
		'std' => '0',
		'type' => 'checkbox');
		
		
	$options[] = array(
		'name' => __('Home Page Image', 'options_framework_theme'),
		'desc' => __('This image appears on the home page between the menu and the first blog post. (for best results the image should be 620px wide - will be resized automatically)', 'options_framework_theme'),
		'id' => 'home_image',
		'type' => 'upload');
		
	$options[] = array(
		'name' => __('Home Page Video', 'options_framework_theme'),
		'desc' => sprintf( __( 'Add content here for the home page between the menu and the first blog post. This box is for anything you want to fit tight to the box with no margin - (text is not recommended)', 'options_framework_theme' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
		'id' => 'home_video',
		'type' => 'editor',
		'settings' => $wp_editor_settings );
	
	$options[] = array(
		'name' => __('Home Page Text', 'options_framework_theme'),
		'desc' => sprintf( __( 'Add content here for the home page between the menu and the first blog post. Anything you add to this box will have a margin on the left and right - (suitable for text)', 'options_framework_theme' ), 'options_framework_theme'),
		'id' => 'home_margin',
		'type' => 'editor');

		


	/**
	 * For $settings options see:
	 * http://codex.wordpress.org/Function_Reference/wp_editor
	 *
	 * 'media_buttons' are not supported as there is no post to attach items to
	 * 'textarea_name' is set by the 'id' you choose
	 */

	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	return $options;
}

/*
 * This is an example of how to add custom scripts to the options panel.
 * This example shows/hides an option when a checkbox is clicked.
 */

add_action('optionsframework_custom_scripts', 'optionsframework_custom_scripts');

function optionsframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function($) {

	$('#example_showhidden').click(function() {
  		$('#section-example_text_hidden').fadeToggle(400);
	});

	if ($('#example_showhidden:checked').val() !== undefined) {
		$('#section-example_text_hidden').show();
	}

});
</script>

<?php
}